@@ -11,6 +11,10 @@ use Gearman::Server;
 use Danga::Socket;
 use IO::Socket::INET;
 
+BEGIN {
+    $ENV{GEARMAN_DRIVER_ADAPTOR} = 'Gearman::Driver::Adaptor::PP';
+}
+
 my ( $host, $port ) = ( '127.0.0.1', 4731 );
 
 $|++;
@@ -19,6 +23,11 @@ sub new {
     return bless {}, shift;
 }
 
+sub run_gearman_server {
+    my $server = Gearman::Server->new( port => $port );
+    Danga::Socket->EventLoop();
+}
+
 sub run_gearmand {
     my ($self) = @_;
 
@@ -31,17 +40,15 @@ sub run_gearmand {
 
         exit(0);
     }
-
-    printf STDERR " " x 10 . "gearmand started (%d) ", $self->{gearmand_pid};
 }
 
 sub run_gearman_driver {
-    my ($self) = @_;
+    my ( $self, @args ) = @_;
 
     unless ( $self->{gearman_driver_pid} = fork ) {
         die "cannot fork: $!" unless defined $self->{gearman_driver_pid};
 
-        my @cmd = ( $^X, "$Bin/gearman_driver.pl" );
+        my @cmd = ( $^X, "$Bin/gearman_driver.pl", @args );
 
         exec @cmd or die "Could not exec $Bin/gearman_driver.pl";
 
@@ -54,8 +61,6 @@ sub run_gearman_driver {
         $cnt++;
         die "Could not connect to 47300 after $cnt seconds" if $cnt == 120;
     }
-
-    printf STDERR "gearman-driver started (%d)", $self->{gearman_driver_pid};
 }
 
 sub check_connection {
@@ -83,21 +88,22 @@ sub gearman_client {
     return $client;
 }
 
-sub gearman_server_run {
-    my $server = Gearman::Server->new( port => $port );
-    Danga::Socket->EventLoop();
-}
-
 sub gearman_driver {
     return Gearman::Driver->new(
         max_idle_time => 5,
         interval      => 1,
         loglevel      => 'DEBUG',
-        namespaces    => [qw(Gearman::Driver::Test::Live)],
+        namespaces    => \@ARGV,
         server        => join( ':', $host, $port ),
     );
 }
 
+sub prepare {
+    my ( $self, @args ) = @_;
+    $self->run_gearmand;
+    $self->run_gearman_driver(@args);
+}
+
 sub telnet_client {
     my $telnet = Net::Telnet->new(
         Timeout => 30,
